from setuptools import setup, find_packages

# List of packages from requirements.txt
install_requires = [
    'annotated-types==0.6.0',
    'anyio==4.3.0',
    'astunparse==1.6.3',
    'blinker==1.7.0',
    'cachelib==0.12.0',
    'certifi==2024.2.2',
    'charset-normalizer==3.3.2',
    'click==8.1.7',
    'colorama==0.4.6',
    'distro==1.9.0',
    'filelock==3.13.4',
    'fsspec==2024.3.1',
    'future==0.18.3',
    'gitdb==4.0.11',
    'GitPython==3.1.43',
    'h11==0.14.0',
    'httpcore==1.0.5',
    'httpx==0.27.0',
    'idna==3.6',
    'iniconfig==2.0.0',
    'itsdangerous==2.1.2',
    'markdown-it-py==3.0.0',
    'MarkupSafe==2.1.5',
    'mdurl==0.1.2',
    'mpmath==1.3.0',
    'msgspec==0.18.6',
    'networkx==3.3',
    'numpy==1.26.4',
    'packaging==24.0',
    'pinecone-client==3.2.2',
    'pluggy==1.5.0',
    'pydantic==2.6.4',
    'pydantic_core==2.16.3',
    'Pygments==2.17.2',
    'pytest==8.1.1',
    'python-dotenv==1.0.1',
    'PyYAML==6.0.1',
    'regex==2024.4.16',
    'requests==2.31.0',
    'rich==13.7.1',
    'safetensors==0.4.3',
    'scipy==1.13.0',
    'six==1.16.0',
    'smart-open==7.0.4',
    'smmap==5.0.1',
    'sniffio==1.3.1',
    'soupsieve==2.5',
    'sympy==1.12',
    'tokenizers==0.19.1',
    'torch==2.2.2',
    'tqdm==4.66.2',
    'typing_extensions==4.11.0',
    'urllib3==2.2.1',
    'Werkzeug==3.0.2',
    'wrapt==1.16.0',
    'zipp==3.18.1',
]

setup(
    name='leya',
    version='0.1.0',
    packages=find_packages(),
    install_requires=install_requires,
    entry_points={
        'console_scripts': [
            'leya=leya.cli:main',
        ],
    },
    author='Pranav Iyer',
    author_email='pn2229@nyu.edu',
    description='A coding assistant to help with repository management and code queries.',
)
